/*******************************************************************************
* File Name: main.c
*
* Version: 2.0
*
* Description: 
*   This is a source code for example project of Filter component.
*
*   Sine wave is connected to +ve input of ADC using the I/O pin P0.0.
*   EOC signal from ADC is connected to data request input of DMA_1 component 
*   On each successful conversion, the ADC output is transferred to Filter 
*   input register using DMA component.
*   Filter component filters the input signal. A low pass filter with  
*   rectangular window is used here. After filtering the input samples,  
*   filter generates a data request signal which is connected to data request 
*   transferred to VDAC input signal of DMA_2. After filtering each of input  
*   samples, the output is data register with the help of DMA component. VDAC 
*   then converts filtered o/p  to analog signal which can be observed using 
*   an oscilloscope from port P0[2] of DVK1.
*
*   LCD is used to display the ADC output register values and also the filter 
*   input and output register values. Observe the filtered output using an 
*   oscilloscope by using the port P0[2] of CY8CKIT-001.
*
* Hardware settings:
*   1. Connect the analog voltage to port P0[0]which is connected to ADC input
*      terminal.
*   2. Observe the VDAC output from I/O port P0[2] using an oscilloscope.
*
********************************************************************************/

#include <device.h>

/* Function prototypes */
void ADC_TO_Filter(void);
void Filter_TO_DAC(void);

/* DMA Configuration for DMA_1 */
#define DMA_1_BYTES_PER_BURST 1
#define DMA_1_REQUEST_PER_BURST 1
#define DMA_1_SRC_BASE (CYDEV_PERIPH_BASE)
#define DMA_1_DST_BASE (CYDEV_PERIPH_BASE)

/* DMA Configuration for DMA_2 */
#define DMA_2_BYTES_PER_BURST 1
#define DMA_2_REQUEST_PER_BURST 1
#define DMA_2_SRC_BASE (CYDEV_PERIPH_BASE)
#define DMA_2_DST_BASE (CYDEV_PERIPH_BASE)


/* Variable declarations for DMA_1 */
uint8 DMA_1_Chan;
uint8 DMA_1_TD[1];

/* Variable declarations for DMA_2 */
uint8 DMA_2_Chan;
uint8 DMA_2_TD[1];


/*******************************************************************************
* Function Name: main
********************************************************************************
* Summary:
*  Main function performs following functions:
*  1: Initializes the Character LCD
*  2: Initializes the VDAC.
*  3: Initializes the Filter.
*  4: Starts the ADC 
*  5: Starts ADC converstion.
*  6: Configures DMA for data transfer.
*  7: Uses LCD to display the results.
*
* Parameters:
*  None.
*
* Return:
*  None.
*
*******************************************************************************/

void main()
{
    /* Start the components */
   //vp LCD_Start();
    VDAC8_Start();
    Filter_Start();
    WaveDAC8_Start();
    /* Set the Filter coherency byte as middle byte */
    Filter_COHER_REG = 0x55; 
    ADC_DelSig_Start();
    
    /* Start the ADC Conversion */
    ADC_DelSig_StartConvert();
    
    /* Configure DMA_1 to start data transfer from ADC output 
       register to Filter input register */
    ADC_TO_Filter();
    
    /* Configurer DMA_2 to start data transfer from Filter output
       register to VDAC input register */
    Filter_TO_DAC();

    for(;;)
    {
        /* To display the ADC output */
        //vp LCD_Position(0, 0);
        //vp LCD_PrintInt16(ADC_DelSig_GetResult16());
        
        /* To read the Filter input register */
        //vp LCD_Position(1, 0);
        //vp LCD_PrintInt8(Filter_STAGEBM_REG);
        
        /* To read the Filter output register */
        //vp LCD_Position(1, 6);
        //vp LCD_PrintInt8(Filter_HOLDBM_REG);
    }
}


/******************************************************************************
* Function: ADC_TO_Filter()
*
* Description:
*   This Funtion configures the DMA_1 to transfer the ADC output to filter 
*   input register.
*
* Parameters:
*   None
*
* Return:
*   None
*
******************************************************************************/

void ADC_TO_Filter()
{
    /* Initialize the DMA channel */
    DMA_1_Chan = DMA_1_DmaInitialize(DMA_1_BYTES_PER_BURST, DMA_1_REQUEST_PER_BURST, 
                 HI16(DMA_1_SRC_BASE), HI16(DMA_1_DST_BASE));
                 
    /* Allocate TD */
    DMA_1_TD[0] = CyDmaTdAllocate();
    
    /* Set TD configuration */
    CyDmaTdSetConfiguration(DMA_1_TD[0], 1, DMA_INVALID_TD, 0);
    
    /* Set the source and destination address */
    CyDmaTdSetAddress(DMA_1_TD[0], LO16((uint32)ADC_DelSig_DEC_SAMP_PTR), 
                      LO16((uint32)Filter_STAGEBM_PTR));
    
    /* Set the initial TD */
    CyDmaChSetInitialTd(DMA_1_Chan, DMA_1_TD[0]);
    
    /* Enable the channel */
    CyDmaChEnable(DMA_1_Chan, 1);
}


/******************************************************************************
* Function: Filter_TO_DAC()
*
* Description:
*   This Funtion configures the DMA_2 to transfer the Filter output to VDAC 
*   data register.
*
* Parameters:
*   None
*
* Return:
*   None
*
******************************************************************************/

void Filter_TO_DAC()
{
    /* Initialize the DMA channel */
    DMA_2_Chan = DMA_2_DmaInitialize(DMA_2_BYTES_PER_BURST, DMA_2_REQUEST_PER_BURST, 
                 HI16(DMA_2_SRC_BASE), HI16(DMA_2_DST_BASE));
                 
    /* Allocate TD */
    DMA_2_TD[0] = CyDmaTdAllocate();
    
    /* Set TD configuration */
    CyDmaTdSetConfiguration(DMA_2_TD[0], 1, DMA_INVALID_TD, 0);
    
    /* Set the source and destination address */
    CyDmaTdSetAddress(DMA_2_TD[0], LO16((uint32)Filter_HOLDBM_PTR), 
                      LO16((uint32)VDAC8_Data_PTR));
    
    /* Set the initial TD */
    CyDmaChSetInitialTd(DMA_2_Chan, DMA_2_TD[0]);
    
    /* Enable the channel */
    CyDmaChEnable(DMA_2_Chan, 1);
}

/* [] END OF FILE */
